@@ -13,7 +13,6 @@ import os.path
 import py_compile
 import re
 
-from typing import Tuple
 
 import pytest
 
@@ -35,18 +34,21 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
 
     def make_mycode(self) -> None:
         """Make the mycode.py file when needed."""
-        self.make_file("mycode.py", """\
+        self.make_file(
+            "mycode.py",
+            """\
             import covmod1
             import covmodzip1
             a = 1
             print('done')
-            """)
+            """,
+        )
 
     def test_report(self) -> None:
         self.make_mycode()
         cov = coverage.Coverage()
         self.start_import_stop(cov, "mycode")
-        assert self.stdout() == 'done\n'
+        assert self.stdout() == "done\n"
         report = self.get_report(cov)
 
         # Name                                           Stmts   Miss  Cover
@@ -151,10 +153,13 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         Ref: https://github.com/nedbat/coveragepy/issues/1604
         """
         self.make_mycode()
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             relative_files = true
-            """)
+            """,
+        )
         self.make_file("submodule/mycode.py", "import mycode")
 
         cov = coverage.Coverage()
@@ -172,10 +177,13 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
 
     def test_report_include_relative_files_and_wildcard_path(self) -> None:
         self.make_mycode()
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             relative_files = true
-            """)
+            """,
+        )
         self.make_file("submodule/mycode.py", "import nested.submodule.mycode")
         self.make_file("nested/submodule/mycode.py", "import mycode")
 
@@ -200,11 +208,14 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         # https://github.com/nedbat/coveragepy/issues/1407
         self.make_file("foo.py", "")
         self.make_file("bar/bar.py", "")
-        self.make_file("tests/test_baz.py", """\
+        self.make_file(
+            "tests/test_baz.py",
+            """\
             def test_foo():
                 assert True
             test_foo()
-            """)
+            """,
+        )
         self.run_command("coverage run --source=. --omit='./*.py' -m tests.test_baz")
         report = self.report_from_command("coverage report")
 
@@ -222,13 +233,16 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
 
     def test_run_source_vs_report_include(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/621
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             source = .
 
             [report]
             include = mod/*,tests/*
-            """)
+            """,
+        )
         # It should be OK to use that configuration.
         cov = coverage.Coverage()
         with self.assert_warnings(cov, []):
@@ -239,13 +253,16 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         # https://github.com/nedbat/coveragepy/issues/622
         # report:omit shouldn't clobber run:omit.
         self.make_mycode()
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             omit = */covmodzip1.py
 
             [report]
             omit = */covmod1.py
-            """)
+            """,
+        )
         self.add_test_modules_to_pythonpath()
         self.run_command("coverage run mycode.py")
 
@@ -257,16 +274,19 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert "covmodzip1.py" not in files
 
     def test_report_branches(self) -> None:
-        self.make_file("mybranch.py", """\
+        self.make_file(
+            "mybranch.py",
+            """\
             def branch(x):
                 if x:
                     print("x")
                 return x
             branch(1)
-            """)
+            """,
+        )
         cov = coverage.Coverage(source=["."], branch=True)
         self.start_import_stop(cov, "mybranch")
-        assert self.stdout() == 'x\n'
+        assert self.stdout() == "x\n"
         report = self.get_report(cov)
 
         # Name          Stmts   Miss Branch BrPart  Cover
@@ -279,7 +299,9 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert self.last_line_squeezed(report) == "TOTAL 5 0 2 1 86%"
 
     def test_report_show_missing(self) -> None:
-        self.make_file("mymissing.py", """\
+        self.make_file(
+            "mymissing.py",
+            """\
             def missing(x, y):
                 if x:
                     print("x")
@@ -294,10 +316,11 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                     pass
                 return x
             missing(0, 1)
-            """)
+            """,
+        )
         cov = coverage.Coverage(source=["."])
         self.start_import_stop(cov, "mymissing")
-        assert self.stdout() == 'y\nz\n'
+        assert self.stdout() == "y\nz\n"
         report = self.get_report(cov, show_missing=True)
 
         # Name           Stmts   Miss  Cover   Missing
@@ -312,17 +335,20 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert squeezed[4] == "TOTAL 14 3 79%"
 
     def test_report_show_missing_branches(self) -> None:
-        self.make_file("mybranch.py", """\
+        self.make_file(
+            "mybranch.py",
+            """\
             def branch(x, y):
                 if x:
                     print("x")
                 if y:
                     print("y")
             branch(1, 1)
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "mybranch")
-        assert self.stdout() == 'x\ny\n'
+        assert self.stdout() == "x\ny\n"
         report = self.get_report(cov, show_missing=True)
 
         # Name           Stmts   Miss Branch BrPart  Cover   Missing
@@ -337,10 +363,15 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert squeezed[4] == "TOTAL 6 0 4 2 80%"
 
     def test_report_show_missing_branches_and_lines(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             import mybranch
-            """)
-        self.make_file("mybranch.py", """\
+            """,
+        )
+        self.make_file(
+            "mybranch.py",
+            """\
             def branch(x, y, z):
                 if x:
                     print("x")
@@ -351,34 +382,41 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                         print("z")
                 return x
             branch(1, 1, 0)
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "main")
-        assert self.stdout() == 'x\ny\n'
+        assert self.stdout() == "x\ny\n"
         report_lines = self.get_report(cov, squeeze=False, show_missing=True).splitlines()
 
         expected = [
-            'Name          Stmts   Miss Branch BrPart  Cover   Missing',
-            '---------------------------------------------------------',
-            'main.py           1      0      0      0   100%',
-            'mybranch.py      10      2      8      3    61%   2->4, 4->6, 7-8',
-            '---------------------------------------------------------',
-            'TOTAL            11      2      8      3    63%',
+            "Name          Stmts   Miss Branch BrPart  Cover   Missing",
+            "---------------------------------------------------------",
+            "main.py           1      0      0      0   100%",
+            "mybranch.py      10      2      8      3    61%   2->4, 4->6, 7-8",
+            "---------------------------------------------------------",
+            "TOTAL            11      2      8      3    63%",
         ]
         assert expected == report_lines
 
     def test_report_skip_covered_no_branches(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             import not_covered
 
             def normal():
                 print("z")
             normal()
-            """)
-        self.make_file("not_covered.py", """\
+            """,
+        )
+        self.make_file(
+            "not_covered.py",
+            """\
             def not_covered():
                 print("n")
-            """)
+            """,
+        )
         # --fail-under is handled by cmdline.py, use real commands.
         out = self.run_command("coverage run main.py")
         assert out == "z\n"
@@ -400,7 +438,9 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert self.last_command_status == 0
 
     def test_report_skip_covered_branches(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             import not_covered, covered
 
             def normal(z):
@@ -408,18 +448,25 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                     print("z")
             normal(True)
             normal(False)
-            """)
-        self.make_file("not_covered.py", """\
+            """,
+        )
+        self.make_file(
+            "not_covered.py",
+            """\
             def not_covered(n):
                 if n:
                     print("n")
             not_covered(True)
-            """)
-        self.make_file("covered.py", """\
+            """,
+        )
+        self.make_file(
+            "covered.py",
+            """\
             def foo():
                 pass
             foo()
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "main")
         assert self.stdout() == "n\nz\n"
@@ -440,7 +487,9 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert squeezed[6] == "2 files skipped due to complete coverage."
 
     def test_report_skip_covered_branches_with_totals(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             import not_covered
             import also_not_run
 
@@ -449,17 +498,24 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                     print("z")
             normal(True)
             normal(False)
-            """)
-        self.make_file("not_covered.py", """\
+            """,
+        )
+        self.make_file(
+            "not_covered.py",
+            """\
             def not_covered(n):
                 if n:
                     print("n")
             not_covered(True)
-            """)
-        self.make_file("also_not_run.py", """\
+            """,
+        )
+        self.make_file(
+            "also_not_run.py",
+            """\
             def does_not_appear_in_this_film(ni):
                 print("Ni!")
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "main")
         assert self.stdout() == "n\nz\n"
@@ -482,11 +538,14 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert squeezed[7] == "1 file skipped due to complete coverage."
 
     def test_report_skip_covered_all_files_covered(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             def foo():
                 pass
             foo()
-            """)
+            """,
+        )
         cov = coverage.Coverage(source=["."], branch=True)
         self.start_import_stop(cov, "main")
         assert self.stdout() == ""
@@ -512,13 +571,13 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
 
         assert self.line_count(report) == 5, report
         assert report.split("\n")[0] == (
-            '| Name      |    Stmts |     Miss |   Branch |   BrPart |    Cover |'
+            "| Name      |    Stmts |     Miss |   Branch |   BrPart |    Cover |"
         )
         assert report.split("\n")[1] == (
-            '|---------- | -------: | -------: | -------: | -------: | -------: |'
+            "|---------- | -------: | -------: | -------: | -------: | -------: |"
         )
         assert report.split("\n")[2] == (
-            '| **TOTAL** |    **3** |    **0** |    **0** |    **0** | **100%** |'
+            "| **TOTAL** |    **3** |    **0** |    **0** |    **0** | **100%** |"
         )
         squeezed = self.squeezed_lines(report)
         assert squeezed[4] == "1 file skipped due to complete coverage."
@@ -527,11 +586,14 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert total == "100\n"
 
     def test_report_skip_covered_longfilename(self) -> None:
-        self.make_file("long_______________filename.py", """\
+        self.make_file(
+            "long_______________filename.py",
+            """\
             def foo():
                 pass
             foo()
-            """)
+            """,
+        )
         cov = coverage.Coverage(source=["."], branch=True)
         self.start_import_stop(cov, "long_______________filename")
         assert self.stdout() == ""
@@ -557,13 +619,16 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         self.assert_doesnt_exist(".coverage")
 
     def test_report_skip_empty(self) -> None:
-        self.make_file("main.py", """\
+        self.make_file(
+            "main.py",
+            """\
             import submodule
 
             def normal():
                 print("z")
             normal()
-            """)
+            """,
+        )
         self.make_file("submodule/__init__.py", "")
         cov = coverage.Coverage()
         self.start_import_stop(cov, "main")
@@ -602,12 +667,17 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert report.split("\n")[4] == "1 empty file skipped."
 
     def test_report_precision(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [report]
             precision = 3
             omit = */site-packages/*
-            """)
-        self.make_file("main.py", """\
+            """,
+        )
+        self.make_file(
+            "main.py",
+            """\
             import not_covered, covered
 
             def normal(z):
@@ -615,18 +685,25 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                     print("z")
             normal(True)
             normal(False)
-            """)
-        self.make_file("not_covered.py", """\
+            """,
+        )
+        self.make_file(
+            "not_covered.py",
+            """\
             def not_covered(n):
                 if n:
                     print("n")
             not_covered(True)
-            """)
-        self.make_file("covered.py", """\
+            """,
+        )
+        self.make_file(
+            "covered.py",
+            """\
             def foo():
                 pass
             foo()
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "main")
         assert self.stdout() == "n\nz\n"
@@ -647,11 +724,14 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert squeezed[6] == "TOTAL 13 0 4 1 94.118%"
 
     def test_report_precision_all_zero(self) -> None:
-        self.make_file("not_covered.py", """\
+        self.make_file(
+            "not_covered.py",
+            """\
             def not_covered(n):
                 if n:
                     print("n")
-            """)
+            """,
+        )
         self.make_file("empty.py", "")
         cov = coverage.Coverage(source=["."])
         self.start_import_stop(cov, "empty")
@@ -669,6 +749,40 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert "not_covered.py       3      3   0.000000%" in report
         assert "TOTAL                3      3   0.000000%" in report
 
+    def test_report_module_docstrings(self) -> None:
+        self.make_file(
+            "main.py",
+            """\
+            # Line 1
+            '''Line 2 docstring.'''
+            import other
+            a = 4
+            """,
+        )
+        self.make_file(
+            "other.py",
+            """\
+            '''Line 1'''
+            a = 2
+            """,
+        )
+        cov = coverage.Coverage()
+        self.start_import_stop(cov, "main")
+        report = self.get_report(cov)
+
+        # Name       Stmts   Miss  Cover
+        # ------------------------------
+        # main.py        2      0   100%
+        # other.py       1      0   100%
+        # ------------------------------
+        # TOTAL          3      0   100%
+
+        assert self.line_count(report) == 6, report
+        squeezed = self.squeezed_lines(report)
+        assert squeezed[2] == "main.py 2 0 100%"
+        assert squeezed[3] == "other.py 1 0 100%"
+        assert squeezed[5] == "TOTAL 3 0 100%"
+
     def test_dotpy_not_python(self) -> None:
         # We run a .py file, and when reporting, we can't parse it as Python.
         # We should get an error message in the report.
@@ -686,11 +800,11 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         self.make_file("\xe2/accented.py", "print('accented')")
         self.make_data_file(lines={abs_file("\xe2/accented.py"): [1]})
         report_expected = (
-            "Name            Stmts   Miss  Cover\n" +
-            "-----------------------------------\n" +
-            "\xe2/accented.py       1      0   100%\n" +
-            "-----------------------------------\n" +
-            "TOTAL               1      0   100%\n"
+            "Name            Stmts   Miss  Cover\n"
+            + "-----------------------------------\n"
+            + "\xe2/accented.py       1      0   100%\n"
+            + "-----------------------------------\n"
+            + "TOTAL               1      0   100%\n"
         )
         cov = coverage.Coverage()
         cov.load()
@@ -709,20 +823,21 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         with pytest.raises(NotPython, match=msg):
             self.get_report(cov, morfs=["accented\xe2.py"])
 
-    def test_dotpy_not_python_ignored(self) -> None:
-        # We run a .py file, and when reporting, we can't parse it as Python,
+    @pytest.mark.parametrize("filename", ["mycode.py", "my_script"])
+    def test_dotpy_not_python_ignored(self, filename: str) -> None:
+        # We run a Python file, and when reporting, we can't parse it as Python,
         # but we've said to ignore errors, so there's no error reported,
         # though we still get a warning.
-        self.make_file("mycode.py", "This isn't python at all!")
-        self.make_data_file(lines={"mycode.py": [1]})
+        self.make_file(filename, "This isn't python at all! I can't cope.")
+        self.make_data_file(lines={filename: [1]})
         cov = coverage.Coverage()
         cov.load()
         with pytest.raises(NoDataError, match="No data to report."):
             with pytest.warns(Warning) as warns:
-                self.get_report(cov, morfs=["mycode.py"], ignore_errors=True)
+                self.get_report(cov, morfs=[filename], ignore_errors=True)
         assert_coverage_warnings(
             warns,
-            re.compile(r"Couldn't parse Python file '.*[/\\]mycode.py' \(couldnt-parse\)"),
+            re.compile(rf"Couldn't parse Python file '.*[/\\]{filename}' \(couldnt-parse\)"),
         )
 
     def test_dothtml_not_python(self) -> None:
@@ -738,7 +853,9 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
             self.get_report(cov, morfs=["mycode.html"])
 
     def test_report_no_extension(self) -> None:
-        self.make_file("xxx", """\
+        self.make_file(
+            "xxx",
+            """\
             # This is a python file though it doesn't look like it, like a main script.
             a = b = c = d = 0
             a = 3
@@ -747,7 +864,8 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                 c = 6
             d = 7
             print(f"xxx: {a} {b} {c} {d}")
-            """)
+            """,
+        )
         self.make_data_file(lines={abs_file("xxx"): [2, 3, 4, 5, 7, 8]})
         cov = coverage.Coverage()
         cov.load()
@@ -755,13 +873,16 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert self.last_line_squeezed(report) == "TOTAL 7 1 86%"
 
     def test_report_with_chdir(self) -> None:
-        self.make_file("chdir.py", """\
+        self.make_file(
+            "chdir.py",
+            """\
             import os
             print("Line One")
             os.chdir("subdir")
             print("Line Two")
-            print(open("something").read())
-            """)
+            print(open("something", encoding="utf-8").read())
+            """,
+        )
         self.make_file("subdir/something", "hello")
         out = self.run_command("coverage run --source=. chdir.py")
         assert out == "Line One\nLine Two\nhello\n"
@@ -772,16 +893,22 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
 
     def test_bug_156_file_not_run_should_be_zero(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/156
-        self.make_file("mybranch.py", """\
+        self.make_file(
+            "mybranch.py",
+            """\
             def branch(x):
                 if x:
                     print("x")
                 return x
             branch(1)
-            """)
-        self.make_file("main.py", """\
+            """,
+        )
+        self.make_file(
+            "main.py",
+            """\
             print("y")
-            """)
+            """,
+        )
         cov = coverage.Coverage(branch=True, source=["."])
         self.start_import_stop(cov, "main")
         report = self.get_report(cov).splitlines()
@@ -812,17 +939,23 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
     @pytest.mark.skipif(not env.WINDOWS, reason=".pyw files are only on Windows.")
     def test_pyw_files(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/261
-        self.make_file("start.pyw", """\
+        self.make_file(
+            "start.pyw",
+            """\
             import mod
             print("In start.pyw")
-            """)
-        self.make_file("mod.pyw", """\
+            """,
+        )
+        self.make_file(
+            "mod.pyw",
+            """\
             print("In mod.pyw")
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         # start_import_stop can't import the .pyw file, so use the long form.
         with cov.collect():
-            import start    # pylint: disable=import-error, unused-import
+            import start  # pylint: disable=import-error, unused-import
 
         report = self.get_report(cov)
         assert "NoSource" not in report
@@ -891,7 +1024,9 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert "|        0 |        0 |        0 |        0 |     100% |" in report
 
     def test_markdown_with_missing(self) -> None:
-        self.make_file("mymissing.py", """\
+        self.make_file(
+            "mymissing.py",
+            """\
             def missing(x, y):
                 if x:
                     print("x")
@@ -906,10 +1041,11 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
                     pass
                 return x
             missing(0, 1)
-            """)
+            """,
+        )
         cov = coverage.Coverage(source=["."])
         self.start_import_stop(cov, "mymissing")
-        assert self.stdout() == 'y\nz\n'
+        assert self.stdout() == "y\nz\n"
         report = self.get_report(cov, squeeze=False, output_format="markdown", show_missing=True)
 
         # | Name         |    Stmts |     Miss |   Cover |   Missing |
@@ -926,14 +1062,17 @@ class SummaryTest(UsingModulesMixin, CoverageTest):
         assert self.get_report(cov, output_format="total", precision=4) == "78.5714\n"
 
     def test_bug_1524(self) -> None:
-        self.make_file("bug1524.py", """\
+        self.make_file(
+            "bug1524.py",
+            """\
             class Mine:
                 @property
                 def thing(self) -> int:
                     return 17
 
             print(Mine().thing)
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         self.start_import_stop(cov, "bug1524")
         assert self.stdout() == "17\n"
@@ -947,7 +1086,9 @@ class ReportingReturnValueTest(CoverageTest):
 
     def run_coverage(self) -> Coverage:
         """Run coverage on doit.py and return the coverage object."""
-        self.make_file("doit.py", """\
+        self.make_file(
+            "doit.py",
+            """\
             a = 1
             b = 2
             c = 3
@@ -955,7 +1096,8 @@ class ReportingReturnValueTest(CoverageTest):
             if a > 10:
                 f = 6
             g = 7
-            """)
+            """,
+        )
 
         cov = coverage.Coverage()
         self.start_import_stop(cov, "doit")
@@ -994,7 +1136,7 @@ class SummaryReporterConfigurationTest(CoverageTest):
         source += "    a = 2\n" * dont_run
         self.make_file(filename, source)
 
-    def get_summary_text(self, *options: Tuple[str, TConfigValueIn]) -> str:
+    def get_summary_text(self, *options: tuple[str, TConfigValueIn]) -> str:
         """Get text output from the SummaryReporter.
 
         The arguments are tuples: (name, value) for Coverage.set_option.
@@ -1027,7 +1169,7 @@ class SummaryReporterConfigurationTest(CoverageTest):
         # TOTAL        586    386    34%
         lines = report.splitlines()[2:-2]
         assert len(lines) == 3
-        nums = [list(map(int, l.replace('%', '').split()[1:])) for l in lines]
+        nums = [list(map(int, l.replace("%", "").split()[1:])) for l in lines]
         # [
         #  [339, 155, 54],
         #  [ 13,   3, 77],
@@ -1040,14 +1182,14 @@ class SummaryReporterConfigurationTest(CoverageTest):
     def test_defaults(self) -> None:
         """Run the report with no configuration options."""
         report = self.get_summary_text()
-        assert 'Missing' not in report
-        assert 'Branch' not in report
+        assert "Missing" not in report
+        assert "Branch" not in report
 
     def test_print_missing(self) -> None:
         """Run the report printing the missing lines."""
-        report = self.get_summary_text(('report:show_missing', True))
-        assert 'Missing' in report
-        assert 'Branch' not in report
+        report = self.get_summary_text(("report:show_missing", True))
+        assert "Missing" in report
+        assert "Branch" not in report
 
     def assert_ordering(self, text: str, *words: str) -> None:
         """Assert that the `words` appear in order in `text`."""
@@ -1063,42 +1205,42 @@ class SummaryReporterConfigurationTest(CoverageTest):
 
     def test_sort_report_by_name(self) -> None:
         # Sort the text report explicitly by the Name column.
-        report = self.get_summary_text(('report:sort', 'Name'))
+        report = self.get_summary_text(("report:sort", "Name"))
         self.assert_ordering(report, "file1.py", "file2.py", "file10.py")
 
     def test_sort_report_by_stmts(self) -> None:
         # Sort the text report by the Stmts column.
-        report = self.get_summary_text(('report:sort', 'Stmts'))
+        report = self.get_summary_text(("report:sort", "Stmts"))
         self.assert_ordering(report, "file2.py", "file10.py", "file1.py")
 
     def test_sort_report_by_missing(self) -> None:
         # Sort the text report by the Missing column.
-        report = self.get_summary_text(('report:sort', 'Miss'))
+        report = self.get_summary_text(("report:sort", "Miss"))
         self.assert_ordering(report, "file2.py", "file1.py", "file10.py")
 
     def test_sort_report_by_cover(self) -> None:
         # Sort the text report by the Cover column.
-        report = self.get_summary_text(('report:sort', 'Cover'))
+        report = self.get_summary_text(("report:sort", "Cover"))
         self.assert_ordering(report, "file10.py", "file1.py", "file2.py")
 
     def test_sort_report_by_cover_plus(self) -> None:
         # Sort the text report by the Cover column, including the explicit + sign.
-        report = self.get_summary_text(('report:sort', '+Cover'))
+        report = self.get_summary_text(("report:sort", "+Cover"))
         self.assert_ordering(report, "file10.py", "file1.py", "file2.py")
 
     def test_sort_report_by_cover_reversed(self) -> None:
         # Sort the text report by the Cover column reversed.
-        report = self.get_summary_text(('report:sort', '-Cover'))
+        report = self.get_summary_text(("report:sort", "-Cover"))
         self.assert_ordering(report, "file2.py", "file1.py", "file10.py")
 
     def test_sort_report_by_invalid_option(self) -> None:
         # Sort the text report by a nonsense column.
         msg = "Invalid sorting option: 'Xyzzy'"
         with pytest.raises(ConfigError, match=msg):
-            self.get_summary_text(('report:sort', 'Xyzzy'))
+            self.get_summary_text(("report:sort", "Xyzzy"))
 
     def test_report_with_invalid_format(self) -> None:
         # Ask for an invalid format.
         msg = "Unknown report format choice: 'xyzzy'"
         with pytest.raises(ConfigError, match=msg):
-            self.get_summary_text(('report:format', 'xyzzy'))
+            self.get_summary_text(("report:format", "xyzzy"))
